@@ -35,7 +35,7 @@ class Energidataservice:
         df = pd.DataFrame(indata_list)
         df = df.pivot_table(index='HourUTC', columns='PriceArea', values='SpotPriceEUR')
         df = df.ffill()
-        df.columns = [f'Spotprice {c}' for c in df.columns]
+        # df.columns = [f'Spotprice {c}' for c in df.columns]
         return df
 
     @staticmethod
